@@ -1,5 +1,5 @@
 ## File Name: attach_environment.R
-## File Version: 0.04
+## File Version: 0.05
 
 
 #######################################
@@ -7,7 +7,7 @@
 attach_environment <- function( res, envir )
 {
     CC <- length(res)
-    for (cc in 1:CC){
+    for (cc in 1L:CC){
         assign( names(res)[cc], res[[cc]], envir=envir )
     }
 }
