@@ -1,7 +1,8 @@
 ## File Name: cdm_pem_parameter_sequence_initial_iterations.R
-## File Version: 0.02
+## File Version: 0.04
 
-cdm_pem_parameter_sequence_initial_iterations <- function( pem_parm, pem_parameter_sequence, iter )
+cdm_pem_parameter_sequence_initial_iterations <- function( pem_parm,
+                        pem_parameter_sequence, iter )
 {
     if (iter < 3){
         for (ii in 0:2){
