@@ -1,9 +1,9 @@
 ## File Name: cdm_print_summary_information_criteria_one_criterium.R
-## File Version: 0.03
+## File Version: 0.042
 
 
-cdm_print_summary_information_criteria_one_criterium <- function(object, crit_name, labels,
-        digits_crit, digits_penalty)
+cdm_print_summary_information_criteria_one_criterium <- function(object, crit_name,
+                    labels, digits_crit, digits_penalty)
 {
     deviance <- object$ic$deviance
     crit <- object$ic[[ crit_name ]]
