@@ -1,11 +1,11 @@
 ## File Name: gdina_attribute_structure_hogdina.R
-## File Version: 0.13
+## File Version: 0.142
 
 gdina_attribute_structure_hogdina <- function(G, attr.prob, attr.patt, wgt.theta,
             HOGDINA, a.attr, b.attr, theta.k, tetrachoric )
 {
     tetrachoric0 <- list()
-    for (gg in 1:G){
+    for (gg in 1L:G){
         if (G==1){ ap.gg <- attr.prob
         } else {
             ap.gg <- attr.prob[,gg]
@@ -14,8 +14,9 @@ gdina_attribute_structure_hogdina <- function(G, attr.prob, attr.patt, wgt.theta
         if ( ! is.null(tetrachoric ) ){
             tetrachoric_init <- tetrachoric[[gg]]
         }
-        res <- gdina_attr_rpf_hogdina( attr.patt=attr.patt, attr.prob=ap.gg, theta.k=theta.k,
-                    wgt.theta=wgt.theta[,gg], HOGDINA=HOGDINA, tetrachoric=tetrachoric_init )
+        res <- gdina_attr_rpf_hogdina( attr.patt=attr.patt, attr.prob=ap.gg,
+                        theta.k=theta.k, wgt.theta=wgt.theta[,gg], HOGDINA=HOGDINA,
+                        tetrachoric=tetrachoric_init )
         tetrachoric0[[gg]] <- res$tetrachoric
         if (G==1){
             attr.prob <- res$attr.prob
